# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .voice_response import VoiceResponse

__all__ = ["VoiceListResponse"]

VoiceListResponse = List[VoiceResponse]
